@@ -8,14 +8,7 @@ Why does this file exist, and why __main__? For more info, read:
 - https://docs.python.org/2/using/cmdline.html#cmdoption-m
 - https://docs.python.org/3/using/cmdline.html#cmdoption-m
 """
-from sys import stdout
-
 from .cli import main
 
 if __name__ == "__main__":
-    FNAME_SCRIPTS = main()
-    stdout.write(
-        'Script generated: \n' +
-        '\n'.join(FNAME_SCRIPTS) +
-        '\n'
-    )
+    main()
